Lage/Redigere bilde

Lage/Redigere bilde | IF

Funksjonen "Lage/Redigere bilde" åpner eit nytt vindauge som ser ut som bildet nedanfor.
I dette vindauget skriver du inn URL:en til bildet du vil lenke til samt ein bildebeskrivelse, denne beskrivelsen kommer til å vises som ein alternativ tekst til bildet.
Feltforklaring:

Bildets URL | URL/søkevei til bildet.
Bildets beskrivelse | Bildets beskrivelse, denne beskrivelsen kommer til å vises som ein alternativ tekst til bildet.
Dimensjoner | Bildets bredde og høgde.
Justering | Bildets justering, kan vere anvendelig når man vil at tekst skal flyte rundt bildet.
Ramme | Bilderammens bredde.
Vertikalt tomrom | Vertikalt tomrom , kan vere anvendelig når man vil at tekst skal flyte rundt bildet.
Horisontalt tomrom | Horisontalt tomrom, kan vere anvendelig når man vil at tekst skal flyte rundt bildet.

Gå til: Innhaldsoversikt | Toppen